# -*- coding: UTF-8 -*-
strings = {
    u"フライング・スヌーピー" : u"The Flying Snoopy",
    u"スヌーピーのグレートレース™" : u"Snoopy's Great Race",
    u"ハローキティのカップケーキ・ドリーム" : u"Hello Kitty's Cupcake Dream",
    u"ジュラシック・パーク・ザ・ライド®\n※ご利用には整理券が必要です" : u"Jurassic Park: The Ride",
    u"バック・トゥ・ザ・フューチャー®・ザ・ライド" : u"Back to the Future: The Ride",
    u"フライト・オブ・ザ・ヒッポグリフ™" : u"Flight of the Hippogriff",
    u"スペース・ファンタジー・ザ・ライド" : u"Space Fantasy: The Ride",
    u"アメージング・アドベンチャー・オブ・スパイダーマン・ザ・ライド 4K3D" : u"The Amazing Adventures of Spiderman: 4K3D",
    u"ハリウッド・ドリーム・ザ・ライド" : u"Hollywood Dream: The Ride",
    u"ハリー・ポッター・アンド・ザ・フォービドゥン・ジャーニー™" : u"Harry Potter and the Forbidden Journey",
    u"ハリウッド・ドリーム・ザ・ライド～バックドロップ～" : u"Hollywood Dream: The Ride - Backdrop",
    u"バックドラフト®" : u"Backdraft",
    u"ジョーズ®" : u"Jaws",
    u"エヴァンゲリオン・ザ・リアル 4-D": u"Evangelion-the-Real 4-D",
    u"セサミストリート 4-D ムービーマジック™": u"Sesame Street 4-D Movie Magic",
    u"フロッグ・クワイア": u"Frog Choir",
    u"ウォーターワールド®": u"Waterworld",
    u"バイオハザード®・ザ・エスケープ\n※専用チケット（有料）が必要です" : u"Resident Evil",
    u"リアル・アイルー" : u"Real Airou",
    u"トライウィザード・スピリット・ラリー" : u"Tri-Wizard Spirit Rally",
    u"ユニバーサル・モンスター・ライブ・ロックンロール・ショー®" : u"Universal Monster Live Rock and Roll Show",
    u"日本アニメ（ーター）見本市\nIN UNIVERSAL STUDIOS JAPAN" : u"Japanese Animation Fair",
    u"休止中" : u"Closed",
    u"ターミネーター 2:3-D®" : u"Terminator 2 3:D",
    u"モッピーのバルーン・トリップ" : u"Moppy's Balloon Trip",
    u"エルモのゴーゴー・スケートボード" : u"Elmo's Go-Go Skateboard",
    u"R&B\"ザ・ミックス\"" : u"R&B The Mix",
    u"フュージョン・ダンス・ビート" : u"Fusion Dance Beat",
    u"ミニオン・フィーバー" : u"Minion Fever",
    u"クッキーモンスターのくいしんぼうクッキング\n※専用のチケット(有料)が必要です" : u"Cookie Monster Slide",
    u"フラッシュ・バンド・ビート 2015" : u"Flash Band Beat 2015",
    u"マジカル・スターライト・パレード" : u"Magical Starlight Parade",
    u"ザ・ヴァイオリン・ジャム・カルテット" : u"The Violin Jam Quartet"

}
